@@ -1,46 +1,67 @@
-from lcrequests.tokens import V4PasetoToken
+from lcrequests.tokens import V4PasetoToken as V4PasetoTokenBase
 from lcrequests.typehints import Subject
-from lcrequests.umbrella import CENTRAL, DRAWBRIDGE
+from lcrequests.umbrella import (
+    ASPEN,
+    BEACON,
+    CENTRAL,
+    CLAVIS,
+    DRAWBRIDGE,
+    VISION_MARKET,
+)
+
+
+# ---------------------------------------------------------------------------
+class V4PasetoToken(V4PasetoTokenBase):
+
+    def __init__(self, *args, **kwargs):
+        if 'user_cid' not in kwargs:
+            kwargs['user_cid'] = self.user_cid
+        super().__init__(*args, **kwargs)
 
 
 # ---------------------------------------------------------------------------
 class AspenPortalToken(V4PasetoToken):
     """
-    Token class to use for communications to Aspen CA Server.
+    Token class to use for communications originating from Aspen CA Server.
     """
     subject = Subject.Aspen
+    user_cid = ASPEN.cid
 
 
 # ---------------------------------------------------------------------------
 class BeaconPortalToken(V4PasetoToken):
     """
-    Token class to use for communications to Beacon MDM Server.
+    Token class to use for communications originating from Beacon MDM Server.
     """
     subject = Subject.Beacon
+    user_cid = BEACON.cid
 
 
 # ---------------------------------------------------------------------------
 class ClavisPortalToken(V4PasetoToken):
     """
-    Token class to use for communications to Clavis SSO Server.
+    Token class to use for communications originating from Clavis SSO Server.
     """
     subject = Subject.Clavis
+    user_cid = CLAVIS.cid
 
 
 # ---------------------------------------------------------------------------
 class DrawBridgePortalToken(V4PasetoToken):
     """
-    Token class to use for communications to DrawBridge Portals.
+    Token class to use for communications originating from DrawBridge Portals.
     """
     subject = Subject.DrawBridge
+    user_cid = DRAWBRIDGE.cid
 
 
 # ---------------------------------------------------------------------------
 class VisionMarketToken(V4PasetoToken):
     """
-    Token class to use for communications to Vision Market Portals.
+    Token class to use for communications originating from Vision Market Portals.
     """
     subject = Subject.VisionMarket
+    user_cid = VISION_MARKET.cid
 
 
 # ---------------------------------------------------------------------------
@@ -50,13 +71,3 @@ class UmbrellaTokenCentral(V4PasetoToken):
     """
     subject = Subject.Umbrella
     user_cid = CENTRAL.cid
-
-    def __init__(self, *args, **kwargs):
-        if 'user_cid' not in kwargs:
-            kwargs['user_cid'] = self.user_cid
-        super().__init__(*args, **kwargs)
-
-
-# ---------------------------------------------------------------------------
-class UmbrellaTokenDrawBridge(UmbrellaTokenCentral):
-    user_cid = DRAWBRIDGE.cid
