@@ -15,7 +15,7 @@ if TYPE_CHECKING:
 from .tokens import (
     V4PasetoToken,
     UmbrellaTokenCentral,
-    UmbrellaTokenDrawBridge,
+    DrawBridgePortalToken as UmbrellaTokenDrawBridge,  # TODO - remove TOKEN_CLASS property below
 )
 from .typehints import DELETE, GET, HEAD, PATCH, POST, PUT
 
